import React__default, { createElement, useState } from 'react';
import { StylesProvider } from '@material-ui/core/styles';
import classNames from 'classnames';
import { Grid, IconButton, Select, MenuItem, makeStyles, Typography, Paper, List, ListItem, ListItemText, Divider, ClickAwayListener } from '@material-ui/core';
import { toDate, isValid, max, min, isSameMonth, addMonths, isSameDay, isWithinInterval, startOfWeek, startOfMonth, endOfWeek, endOfMonth, isBefore, addDays, addWeeks, getMonth, getYear, setMonth, setYear, format, isToday, getDate, differenceInCalendarMonths, addYears, isAfter } from 'date-fns';
import { enGB } from 'date-fns/locale';
import ArrowRightAlt from '@material-ui/icons/ArrowRightAlt';
import ChevronLeft from '@material-ui/icons/ChevronLeft';
import ChevronRight from '@material-ui/icons/ChevronRight';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var identity = function identity(x) {
  return x;
};
var chunks = function chunks(array, size) {
  return Array.from({
    length: Math.ceil(array.length / size)
  }, function (_v, i) {
    return array.slice(i * size, i * size + size);
  });
};
var combine = function combine() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return args.filter(identity).join(' ');
};
var getDaysInMonth = function getDaysInMonth(date, locale, weekStartsOn) {
  var startWeek = startOfWeek(startOfMonth(date), {
    locale: locale,
    weekStartsOn: weekStartsOn
  });
  var endWeek = endOfWeek(endOfMonth(date), {
    locale: locale,
    weekStartsOn: weekStartsOn
  });
  var days = [];

  for (var curr = startWeek; isBefore(curr, endWeek);) {
    days.push(curr);
    curr = addDays(curr, 1);
  }

  return days;
};
var isStartOfRange = function isStartOfRange(_ref, day) {
  var startDate = _ref.startDate;
  return startDate && isSameDay(day, startDate);
};
var isEndOfRange = function isEndOfRange(_ref2, day) {
  var endDate = _ref2.endDate;
  return endDate && isSameDay(day, endDate);
};
var inDateRange = function inDateRange(_ref3, day) {
  var startDate = _ref3.startDate,
      endDate = _ref3.endDate;
  return startDate && endDate && (isWithinInterval(day, {
    start: startDate,
    end: endDate
  }) || isSameDay(day, startDate) || isSameDay(day, endDate));
};
var isRangeSameDay = function isRangeSameDay(_ref4) {
  var startDate = _ref4.startDate,
      endDate = _ref4.endDate;

  if (startDate && endDate) {
    return isSameDay(startDate, endDate);
  }

  return false;
};
var parseOptionalDate = function parseOptionalDate(date, defaultValue) {
  if (date) {
    var parsed = toDate(date);
    if (isValid(parsed)) return parsed;
  }

  return defaultValue;
};
var getValidatedMonths = function getValidatedMonths(range, minDate, maxDate) {
  var startDate = range.startDate,
      endDate = range.endDate;

  if (startDate && endDate) {
    var newStart = max([startDate, minDate]);
    var newEnd = min([endDate, maxDate]);
    return [newStart, isSameMonth(newStart, newEnd) ? addMonths(newStart, 1) : newEnd];
  }

  return [startDate, endDate];
};

var getDefaultRanges = function getDefaultRanges(date, locale) {
  return [{
    label: 'Today',
    startDate: date,
    endDate: date
  }, {
    label: 'Yesterday',
    startDate: addDays(date, -1),
    endDate: addDays(date, -1)
  }, {
    label: 'This Week',
    startDate: startOfWeek(date, {
      locale: locale
    }),
    endDate: endOfWeek(date, {
      locale: locale
    })
  }, {
    label: 'Last Week',
    startDate: startOfWeek(addWeeks(date, -1), {
      locale: locale
    }),
    endDate: endOfWeek(addWeeks(date, -1), {
      locale: locale
    })
  }, {
    label: 'Last 7 Days',
    startDate: addWeeks(date, -1),
    endDate: date
  }, {
    label: 'This Month',
    startDate: startOfMonth(date),
    endDate: endOfMonth(date)
  }, {
    label: 'Last Month',
    startDate: startOfMonth(addMonths(date, -1)),
    endDate: endOfMonth(addMonths(date, -1))
  }];
};

function defaultRanges(locale) {
  return getDefaultRanges(new Date(), locale);
}

var useStyles = /*#__PURE__*/makeStyles(function () {
  return {
    iconContainer: {
      padding: 5
    },
    icon: {
      padding: 10,
      '&:hover': {
        background: 'none'
      }
    }
  };
});

var generateYears = function generateYears(relativeTo, count) {
  var half = Math.floor(count / 2);
  return Array(count).fill(0).map(function (_y, i) {
    return relativeTo.getFullYear() - half + i;
  }); // TODO: make part of the state
};

var Header = function Header(props) {
  var date = props.date,
      setDate = props.setDate,
      nextDisabled = props.nextDisabled,
      prevDisabled = props.prevDisabled,
      onClickNext = props.onClickNext,
      onClickPrevious = props.onClickPrevious,
      locale = props.locale;

  var generateMonths = function generateMonths() {
    var months = [];

    for (var i = 0; i < 12; i++) {
      var _locale$localize;

      months.push((_locale$localize = locale.localize) == null ? void 0 : _locale$localize.month(i, {
        width: 'abbreviated'
      }));
    }

    return months;
  };

  var handleMonthChange = function handleMonthChange(event) {
    setDate(setMonth(date, parseInt(event.target.value)));
  };

  var handleYearChange = function handleYearChange(event) {
    setDate(setYear(date, parseInt(event.target.value)));
  };

  var monthSelectRef = React__default.createRef();
  var yearSelectRef = React__default.createRef();
  var classes = useStyles();
  return React__default.createElement(Grid, {
    container: true,
    justifyContent: "space-between",
    alignItems: "center"
  }, React__default.createElement(Grid, {
    item: true,
    className: classes.iconContainer
  }, React__default.createElement(IconButton, {
    className: classes.icon,
    disabled: prevDisabled,
    onClick: onClickPrevious
  }, React__default.createElement(ChevronLeft, {
    color: prevDisabled ? 'disabled' : 'action'
  }))), React__default.createElement(Grid, {
    item: true
  }, React__default.createElement(Select, {
    value: getMonth(date),
    onChange: handleMonthChange,
    MenuProps: {
      container: monthSelectRef.current
    },
    ref: monthSelectRef
  }, generateMonths().map(function (month, idx) {
    return React__default.createElement(MenuItem, {
      key: month,
      value: idx
    }, month);
  }))), React__default.createElement(Grid, {
    item: true
  }, React__default.createElement(Select, {
    value: getYear(date),
    onChange: handleYearChange,
    MenuProps: {
      container: yearSelectRef.current
    },
    ref: yearSelectRef
  }, generateYears(date, 30).map(function (year) {
    return React__default.createElement(MenuItem, {
      key: year,
      value: year
    }, year);
  }))), React__default.createElement(Grid, {
    item: true,
    className: classes.iconContainer
  }, React__default.createElement(IconButton, {
    className: classes.icon,
    disabled: nextDisabled,
    onClick: onClickNext
  }, React__default.createElement(ChevronRight, {
    color: nextDisabled ? 'disabled' : 'action'
  }))));
};

var useStyles$1 = /*#__PURE__*/makeStyles(function (theme) {
  return {
    leftBorderRadius: {
      borderRadius: '50% 0 0 50%'
    },
    rightBorderRadius: {
      borderRadius: '0 50% 50% 0'
    },
    buttonContainer: {
      display: 'flex'
    },
    button: {
      height: 36,
      width: 36,
      padding: 0
    },
    buttonText: {
      lineHeight: 1.6
    },
    outlined: {
      border: "1px solid " + theme.palette.primary.dark
    },
    filled: {
      '&:hover': {
        backgroundColor: theme.palette.primary.dark
      },
      backgroundColor: theme.palette.primary.dark
    },
    highlighted: {
      backgroundColor: theme.palette.action.hover
    },
    contrast: {
      color: theme.palette.primary.contrastText
    }
  };
});

var Day = function Day(props) {
  var startOfRange = props.startOfRange,
      endOfRange = props.endOfRange,
      disabled = props.disabled,
      highlighted = props.highlighted,
      outlined = props.outlined,
      filled = props.filled,
      onClick = props.onClick,
      onHover = props.onHover,
      value = props.value,
      hidden = props.hidden;
  var classes = useStyles$1();
  return createElement("div", {
    className: combine(classes.buttonContainer, startOfRange && classes.leftBorderRadius, endOfRange && classes.rightBorderRadius, !disabled && highlighted && classes.highlighted)
  }, createElement(IconButton, {
    className: combine(classes.button, !disabled && outlined && classes.outlined, !disabled && filled && classes.filled),
    disabled: disabled,
    onClick: onClick,
    onMouseOver: onHover
  }, createElement(Typography, {
    color: !disabled ? 'textPrimary' : 'textSecondary',
    className: combine(classes.buttonText, !disabled && filled && classes.contrast),
    variant: "body2",
    hidden: hidden
  }, value)));
};

var NavigationAction;

(function (NavigationAction) {
  NavigationAction[NavigationAction["Previous"] = -1] = "Previous";
  NavigationAction[NavigationAction["Next"] = 1] = "Next";
})(NavigationAction || (NavigationAction = {}));

var daysInWeek = 7;
var useStyles$2 = /*#__PURE__*/makeStyles(function () {
  return {
    root: {
      width: 290
    },
    weekDaysContainer: {
      marginTop: 10,
      paddingLeft: 30,
      paddingRight: 30
    },
    daysContainer: {
      paddingLeft: 15,
      paddingRight: 15,
      marginTop: 15,
      marginBottom: 20
    }
  };
});
var Month = function Month(props) {
  var helpers = props.helpers,
      handlers = props.handlers,
      date = props.value,
      dateRange = props.dateRange,
      marker = props.marker,
      locale = props.locale,
      setDate = props.setValue,
      minDate = props.minDate,
      maxDate = props.maxDate,
      navState = props.navState,
      weekStartsOn = props.weekStartsOn,
      showOutsideDays = props.showOutsideDays,
      fixedWeeks = props.fixedWeeks;
  var back = navState[0],
      forward = navState[1];
  var weeks = chunks(getDaysInMonth(date, locale, weekStartsOn), daysInWeek);
  var classes = useStyles$2();
  return createElement(Paper, {
    square: true,
    elevation: 0,
    className: classes.root
  }, createElement(Grid, {
    container: true
  }, createElement(Header, {
    date: date,
    setDate: setDate,
    nextDisabled: !forward,
    prevDisabled: !back,
    onClickPrevious: function onClickPrevious() {
      return handlers.onMonthNavigate(marker, NavigationAction.Previous);
    },
    onClickNext: function onClickNext() {
      return handlers.onMonthNavigate(marker, NavigationAction.Next);
    },
    locale: locale
  }), createElement(WeekDayNames, {
    locale: locale,
    date: date,
    weekStartsOn: weekStartsOn
  }), createElement(Grid, {
    item: true,
    container: true,
    direction: "column",
    justifyContent: "space-between",
    className: classes.daysContainer
  }, weeks.map(function (week, idx) {
    return createElement(Grid, {
      key: idx,
      container: true,
      direction: "row",
      justifyContent: "center"
    }, week.map(function (day) {
      var isStart = isStartOfRange(dateRange, day);
      var isEnd = isEndOfRange(dateRange, day);
      var isRangeOneDay = isRangeSameDay(dateRange);
      var highlighted = inDateRange(dateRange, day) || helpers.inHoverRange(day);
      return createElement(Day, {
        key: format(day, 'MM-dd-yyyy'),
        filled: isStart || isEnd,
        outlined: isToday(day),
        highlighted: highlighted && !isRangeOneDay,
        disabled: !isSameMonth(date, day) || !isWithinInterval(day, {
          start: minDate,
          end: maxDate
        }),
        hidden: !showOutsideDays && !isSameMonth(date, day),
        startOfRange: isStart && !isRangeOneDay,
        endOfRange: isEnd && !isRangeOneDay,
        onClick: function onClick() {
          return handlers.onDayClick(day);
        },
        onHover: function onHover() {
          return handlers.onDayHover(day);
        },
        value: getDate(day)
      });
    }));
  }), fixedWeeks && additionalWeeks(weeks.length).map(function (week) {
    return createElement(Grid, {
      key: randomDate(new Date(2001, 0, 1), new Date(2015, 0, 1)).getTime(),
      container: true,
      direction: "row",
      justifyContent: "center"
    }, week.map(function (day) {
      return createElement(Day, {
        key: format(day, 'MM-dd-yyyy'),
        disabled: true,
        hidden: true,
        value: getDate(day)
      });
    }));
  }))));
};

function randomDate(start, end) {
  return new Date(start.getTime() + Math.random() * (end.getTime() - start.getTime()));
}

var additionalWeeks = function additionalWeeks(weeksLength) {
  var newWeeks = [];
  var maxWeeksInMonth = 6;
  var diff = maxWeeksInMonth - weeksLength;

  if (diff === 0) {
    return newWeeks;
  }

  for (var i = 0; i < diff; i++) {
    var week = [];

    for (var _i = 0; _i < daysInWeek; _i++) {
      var date = randomDate(new Date(2001, 0, 1), new Date(2015, 0, 1));
      week.push(date);
    }

    newWeeks.push(week);
  }

  return newWeeks;
};

var WeekDayNames = function WeekDayNames(props) {
  var locale = props.locale,
      date = props.date,
      weekStartsOn = props.weekStartsOn;
  var firstDateOfWeek = startOfWeek(date, {
    locale: locale,
    weekStartsOn: weekStartsOn
  });
  var shortWeekDaysArray = Array.from(Array(7)).map(function (_e, i) {
    return format(addDays(firstDateOfWeek, i), 'EEEEEE');
  });
  var classes = useStyles$2();
  return createElement(Grid, {
    item: true,
    container: true,
    direction: "row",
    justifyContent: "space-between",
    className: classes.weekDaysContainer
  }, shortWeekDaysArray.map(function (day) {
    return createElement(Typography, {
      key: day,
      color: "textSecondary",
      variant: "caption"
    }, day);
  }));
};

var isSameRange = function isSameRange(first, second) {
  var fStart = first.startDate,
      fEnd = first.endDate;
  var sStart = second.startDate,
      sEnd = second.endDate;

  if (fStart && sStart && fEnd && sEnd) {
    return isSameDay(fStart, sStart) && isSameDay(fEnd, sEnd);
  }

  return false;
};

var DefinedRanges = function DefinedRanges(props) {
  var ranges = props.ranges,
      setRange = props.setRange,
      selectedRange = props.selectedRange;
  return React__default.createElement(List, null, ranges.map(function (range, idx) {
    return React__default.createElement(ListItem, {
      button: true,
      key: idx,
      onClick: function onClick() {
        return setRange(range);
      }
    }, React__default.createElement(ListItemText, {
      primaryTypographyProps: {
        variant: 'body2',
        style: {
          fontWeight: isSameRange(range, selectedRange) ? 'bold' : 'normal'
        }
      }
    }, range.label));
  }));
};

var MARKERS = {
  FIRST_MONTH: /*#__PURE__*/Symbol('firstMonth'),
  SECOND_MONTH: /*#__PURE__*/Symbol('secondMonth')
};
var useStyles$3 = /*#__PURE__*/makeStyles(function (theme) {
  return {
    header: {
      padding: '20px 70px'
    },
    headerItem: {
      flex: 1,
      textAlign: 'center'
    },
    divider: {
      borderLeft: "1px solid " + theme.palette.action.hover,
      marginBottom: 20
    }
  };
});

var Menu = function Menu(props) {
  var ranges = props.ranges,
      dateRange = props.dateRange,
      minDate = props.minDate,
      maxDate = props.maxDate,
      firstMonth = props.firstMonth,
      locale = props.locale,
      setFirstMonth = props.setFirstMonth,
      secondMonth = props.secondMonth,
      setSecondMonth = props.setSecondMonth,
      setDateRange = props.setDateRange,
      helpers = props.helpers,
      handlers = props.handlers,
      popoverProps = props.popoverProps,
      startText = props.startText,
      endText = props.endText,
      weekStartsOn = props.weekStartsOn,
      showOutsideDays = props.showOutsideDays,
      fixedWeeks = props.fixedWeeks;
  var startDate = dateRange.startDate,
      endDate = dateRange.endDate;
  var canNavigateCloser = differenceInCalendarMonths(secondMonth, firstMonth) >= 2;
  var commonProps = {
    dateRange: dateRange,
    minDate: minDate,
    maxDate: maxDate,
    helpers: helpers,
    handlers: handlers
  }; // TODO

  var headerDateFormat = 'MMMM dd, yyyy';
  var classes = useStyles$3();
  return React__default.createElement(Paper, Object.assign({}, popoverProps), React__default.createElement(Grid, {
    container: true,
    direction: "row",
    wrap: "nowrap"
  }, React__default.createElement(Grid, null, React__default.createElement(Grid, {
    container: true,
    className: classes.header,
    alignItems: "center"
  }, React__default.createElement(Grid, {
    item: true,
    className: classes.headerItem
  }, React__default.createElement(Typography, {
    variant: "subtitle1"
  }, startDate ? format(startDate, headerDateFormat) : startText != null ? startText : 'Start')), React__default.createElement(Grid, {
    item: true,
    className: classes.headerItem
  }, React__default.createElement(ArrowRightAlt, {
    color: "action"
  })), React__default.createElement(Grid, {
    item: true,
    className: classes.headerItem
  }, React__default.createElement(Typography, {
    variant: "subtitle1"
  }, endDate ? format(endDate, headerDateFormat) : endText != null ? endText : 'End'))), React__default.createElement(Divider, null), React__default.createElement(Grid, {
    container: true,
    direction: "row",
    justifyContent: "center",
    wrap: "nowrap"
  }, React__default.createElement(Month, Object.assign({}, commonProps, {
    value: firstMonth,
    locale: locale,
    setValue: setFirstMonth,
    navState: [true, canNavigateCloser],
    marker: MARKERS.FIRST_MONTH,
    weekStartsOn: weekStartsOn,
    showOutsideDays: showOutsideDays,
    fixedWeeks: fixedWeeks
  })), React__default.createElement("div", {
    className: classes.divider
  }), React__default.createElement(Month, Object.assign({}, commonProps, {
    value: secondMonth,
    locale: locale,
    setValue: setSecondMonth,
    navState: [canNavigateCloser, true],
    marker: MARKERS.SECOND_MONTH,
    weekStartsOn: weekStartsOn,
    showOutsideDays: showOutsideDays,
    fixedWeeks: fixedWeeks
  })))), React__default.createElement("div", {
    className: classes.divider
  }), React__default.createElement(Grid, null, React__default.createElement(DefinedRanges, {
    selectedRange: dateRange,
    ranges: ranges,
    setRange: setDateRange
  }))));
};

var DateRangePicker = function DateRangePicker(props) {
  var locale = props.locale;
  var open = props.open,
      onChange = props.onChange,
      initialDateRange = props.initialDateRange,
      minDate = props.minDate,
      maxDate = props.maxDate,
      _props$definedRanges = props.definedRanges,
      definedRanges = _props$definedRanges === void 0 ? defaultRanges(locale != null ? locale : enGB) : _props$definedRanges,
      popoverProps = props.popoverProps,
      weekStartsOn = props.weekStartsOn,
      showOutsideDays = props.showOutsideDays,
      fixedWeeks = props.fixedWeeks;
  var today = new Date();
  var minDateValid = parseOptionalDate(minDate, addYears(today, -10));
  var maxDateValid = parseOptionalDate(maxDate, addYears(today, 10));

  var _getValidatedMonths = getValidatedMonths(initialDateRange || {}, minDateValid, maxDateValid),
      initialFirstMonth = _getValidatedMonths[0],
      initialSecondMonth = _getValidatedMonths[1];

  var _React$useState = useState(_extends({}, initialDateRange)),
      dateRange = _React$useState[0],
      setDateRange = _React$useState[1];

  var _React$useState2 = useState(),
      hoverDay = _React$useState2[0],
      setHoverDay = _React$useState2[1];

  var _React$useState3 = useState(initialFirstMonth || today),
      firstMonth = _React$useState3[0],
      setFirstMonth = _React$useState3[1];

  var _React$useState4 = useState(initialSecondMonth || addMonths(firstMonth, 1)),
      secondMonth = _React$useState4[0],
      setSecondMonth = _React$useState4[1];

  var startDate = dateRange.startDate,
      endDate = dateRange.endDate; // handlers

  var setFirstMonthValidated = function setFirstMonthValidated(date) {
    if (isBefore(date, secondMonth)) {
      setFirstMonth(date);
    }
  };

  var setSecondMonthValidated = function setSecondMonthValidated(date) {
    if (isAfter(date, firstMonth)) {
      setSecondMonth(date);
    }
  };

  var setDateRangeValidated = function setDateRangeValidated(range) {
    var newStart = range.startDate,
        newEnd = range.endDate;

    if (newStart && newEnd) {
      range.startDate = newStart = max([newStart, minDateValid]);
      range.endDate = newEnd = min([newEnd, maxDateValid]);
      setDateRange(range);
      onChange(range);
      setFirstMonth(newStart);
      setSecondMonth(isSameMonth(newStart, newEnd) ? addMonths(newStart, 1) : newEnd);
    } else {
      var emptyRange = {};
      setDateRange(emptyRange);
      onChange(emptyRange);
      setFirstMonth(today);
      setSecondMonth(addMonths(firstMonth, 1));
    }
  };

  var onDayClick = function onDayClick(day) {
    if (startDate && !endDate && !isBefore(day, startDate)) {
      var newRange = {
        startDate: startDate,
        endDate: day
      };
      onChange(newRange);
      setDateRange(newRange);
    } else {
      setDateRange({
        startDate: day,
        endDate: undefined
      });
    }

    setHoverDay(day);
  };

  var onMonthNavigate = function onMonthNavigate(marker, action) {
    if (marker === MARKERS.FIRST_MONTH) {
      var firstNew = addMonths(firstMonth, action);
      if (isBefore(firstNew, secondMonth)) setFirstMonth(firstNew);
    } else {
      var secondNew = addMonths(secondMonth, action);
      if (isBefore(firstMonth, secondNew)) setSecondMonth(secondNew);
    }
  };

  var onDayHover = function onDayHover(date) {
    if (startDate && !endDate) {
      if (!hoverDay || !isSameDay(date, hoverDay)) {
        setHoverDay(date);
      }
    }
  }; // helpers


  var inHoverRange = function inHoverRange(day) {
    return startDate && !endDate && hoverDay && isAfter(hoverDay, startDate) && isWithinInterval(day, {
      start: startDate,
      end: hoverDay
    });
  };

  var helpers = {
    inHoverRange: inHoverRange
  };
  var handlers = {
    onDayClick: onDayClick,
    onDayHover: onDayHover,
    onMonthNavigate: onMonthNavigate
  };
  return open ? createElement(Menu, {
    dateRange: dateRange,
    minDate: minDateValid,
    maxDate: maxDateValid,
    ranges: definedRanges,
    firstMonth: firstMonth,
    secondMonth: secondMonth,
    locale: locale != null ? locale : enGB,
    setFirstMonth: setFirstMonthValidated,
    setSecondMonth: setSecondMonthValidated,
    setDateRange: setDateRangeValidated,
    helpers: helpers,
    handlers: handlers,
    popoverProps: popoverProps,
    weekStartsOn: weekStartsOn,
    showOutsideDays: showOutsideDays != null ? showOutsideDays : false,
    fixedWeeks: fixedWeeks != null ? fixedWeeks : false
  }) : null;
};

var useStyles$4 = /*#__PURE__*/makeStyles(function () {
  return {
    dateRangePickerContainer: {
      position: 'relative'
    },
    dateRangePicker: {
      position: 'relative',
      zIndex: 1
    }
  };
});

var DateRangePickerWrapper = function DateRangePickerWrapper(props) {
  var classes = useStyles$4();
  var closeOnClickOutside = props.closeOnClickOutside,
      wrapperClassName = props.wrapperClassName,
      onToggle = props.onToggle;

  var handleToggle = function handleToggle() {
    if (closeOnClickOutside === false) {
      return;
    }

    if (onToggle) {
      onToggle();
    }
  };

  var wrapperClasses = classNames(classes.dateRangePicker, wrapperClassName);
  return createElement(ClickAwayListener, {
    onClickAway: handleToggle
  }, createElement("div", {
    className: classes.dateRangePickerContainer
  }, createElement("div", {
    className: wrapperClasses
  }, createElement(DateRangePicker, Object.assign({}, props)))));
};

// Returns a function which generates unique class names based on counters.
// When new generator function is created, rule counter is reset.
// We need to reset the rule counter for SSR for each request.
//
// Copied from material-ui due to issue https://github.com/callemall/material-ui/issues/8223
var ruleCounter = 0; // Adds a prefix to all generated class names, to avoid conflict with other Material UI instances.

var prefix = 'material-ui-daterange-picker';
function generateClassName(rule, sheet) {
  ruleCounter += 1;

  if (ruleCounter > 1e10) {
    console.warn(['Material-UI: you might have a memory leak.', 'The ruleCounter is not supposed to grow that much.'].join(''));
  }

  if (sheet && sheet.options.meta) {
    return prefix + "-" + sheet.options.meta + "-" + rule.key + "-" + ruleCounter;
  }

  return prefix + "-" + rule.key + "-" + ruleCounter;
}

var DateRangePickerExporter = function DateRangePickerExporter(props) {
  return createElement(StylesProvider, {
    generateClassName: generateClassName
  }, createElement(DateRangePickerWrapper, Object.assign({}, props)));
};

export { DateRangePickerExporter as DateRangePicker };
//# sourceMappingURL=material-ui-daterange-picker.esm.js.map
